@@ -24,6 +24,7 @@
 
 #include "kgx-application.h"
 #include "kgx-drop-target.h"
+#include "kgx-empty.h"
 #include "kgx-marshals.h"
 #include "kgx-pages.h"
 #include "kgx-settings.h"
@@ -67,9 +68,7 @@ struct _KgxTabPrivate {
   KgxDropTarget        *drop_target;
 
   GtkWidget            *stack;
-  GtkWidget            *spinner_revealer;
   GtkWidget            *content;
-  guint                 spinner_timeout;
 
   GtkWidget            *exit_revealer;
   GtkWidget            *exit_message;
@@ -136,7 +135,6 @@ kgx_tab_dispose (GObject *object)
     g_application_unmark_busy (G_APPLICATION (priv->application));
     priv->working = 0;
   }
-  g_clear_handle_id (&priv->spinner_timeout, g_source_remove);
 
   if (priv->notification_id) {
     g_application_withdraw_notification (G_APPLICATION (priv->application),
@@ -257,17 +255,6 @@ search_prev (GtkSearchBar *bar,
 }
 
 
-static void
-start_spinner_timeout_cb (gpointer user_data)
-{
-  KgxTab *self = user_data;
-  KgxTabPrivate *priv = kgx_tab_get_instance_private (self);
-
-  gtk_revealer_set_reveal_child (GTK_REVEALER (priv->spinner_revealer), TRUE);
-  priv->spinner_timeout = 0;
-}
-
-
 static inline void
 set_status (KgxTab    *self,
             KgxStatus  status)
@@ -361,33 +348,6 @@ kgx_tab_get_property (GObject    *object,
 }
 
 
-static void
-kgx_tab_set_is_active (KgxTab   *self,
-                       gboolean active)
-{
-  KgxTabPrivate *priv;
-
-  g_return_if_fail (KGX_IS_TAB (self));
-
-  priv = kgx_tab_get_instance_private (self);
-
-  if (active == priv->is_active) {
-    return;
-  }
-
-  priv->is_active = active;
-
-  if (active && priv->notification_id) {
-    g_application_withdraw_notification (G_APPLICATION (priv->application),
-                                          priv->notification_id);
-    g_clear_pointer (&priv->notification_id, g_free);
-  }
-  g_object_set (self, "needs-attention", FALSE, NULL);
-
-  g_object_notify_by_pspec (G_OBJECT (self), pspecs[PROP_IS_ACTIVE]);
-}
-
-
 static void
 kgx_tab_set_property (GObject      *object,
                       guint         property_id,
@@ -425,7 +385,14 @@ kgx_tab_set_property (GObject      *object,
       priv->tooltip = g_value_dup_string (value);
       break;
     case PROP_IS_ACTIVE:
-      kgx_tab_set_is_active (self, g_value_get_boolean (value));
+      if (kgx_set_boolean_prop (object, pspec, &priv->is_active, value)) {
+        if (priv->is_active && priv->notification_id) {
+          g_application_withdraw_notification (G_APPLICATION (priv->application),
+                                               priv->notification_id);
+          g_clear_pointer (&priv->notification_id, g_free);
+        }
+        g_object_set (self, "needs-attention", FALSE, NULL);
+      }
       break;
     case PROP_CLOSE_ON_QUIT:
       kgx_set_boolean_prop (object, pspec, &priv->close_on_quit, value);
@@ -740,11 +707,14 @@ kgx_tab_class_init (KgxTabClass *klass)
                               G_TYPE_FROM_CLASS (klass),
                               kgx_marshals_VOID__VOIDv);
 
+  g_type_ensure (KGX_TYPE_DROP_TARGET);
+  g_type_ensure (KGX_TYPE_EMPTY);
+  g_type_ensure (KGX_TYPE_TERMINAL);
+
   gtk_widget_class_set_template_from_resource (widget_class,
                                                KGX_APPLICATION_PATH "kgx-tab.ui");
 
   gtk_widget_class_bind_template_child_private (widget_class, KgxTab, stack);
-  gtk_widget_class_bind_template_child_private (widget_class, KgxTab, spinner_revealer);
   gtk_widget_class_bind_template_child_private (widget_class, KgxTab, exit_revealer);
   gtk_widget_class_bind_template_child_private (widget_class, KgxTab, exit_message);
   gtk_widget_class_bind_template_child_private (widget_class, KgxTab, search_entry);
@@ -1137,8 +1107,6 @@ kgx_tab_mark_working (KgxTab *self)
   if (G_LIKELY (was_not_working)) {
     g_application_mark_busy (G_APPLICATION (priv->application));
     g_object_notify_by_pspec (G_OBJECT (self), pspecs[PROP_WORKING]);
-    priv->spinner_timeout =
-      g_timeout_add_once (100, start_spinner_timeout_cb, self);
   }
 }
 
@@ -1159,6 +1127,5 @@ kgx_tab_unmark_working (KgxTab *self)
   if (G_LIKELY (priv->working == 0)) {
     g_application_unmark_busy (G_APPLICATION (priv->application));
     g_object_notify_by_pspec (G_OBJECT (self), pspecs[PROP_WORKING]);
-    g_clear_handle_id (&priv->spinner_timeout, g_source_remove);
   }
 }
