@@ -26,6 +26,7 @@
 #include "kgx-close-dialog.h"
 #include "kgx-pages.h"
 #include "kgx-settings.h"
+#include "kgx-shared-closures.h"
 #include "kgx-terminal.h"
 #include "kgx-theme-switcher.h"
 #include "kgx-utils.h"
@@ -452,6 +453,32 @@ scale_as_label (GObject *object, double scale)
 }
 
 
+static gboolean
+decoration_is_inverted (GObject    *object,
+                        const char *layout)
+{
+  g_auto (GStrv) sides = g_strsplit (layout, ":", 2);
+  int counts[2] = { 0 };
+
+  for (size_t i = 0; i < G_N_ELEMENTS (counts); i++) {
+    g_auto (GStrv) elements = NULL;
+
+    if (sides[i] == NULL)
+      continue;
+
+    elements = g_strsplit (sides[i], ",", -1);
+
+    for (size_t j = 0; elements[j]; j++) {
+      if (g_str_equal (elements[j], "close")) {
+        counts[i]++;
+      }
+    }
+  }
+
+  return counts[0] > counts[1];
+}
+
+
 static void
 close_tab_activated (GtkWidget  *widget,
                      const char *action_name,
@@ -526,7 +553,7 @@ about_activated  (GtkWidget  *widget,
   g_autofree char *copyright = NULL;
 
   /* Translators: %s is the year range */
-  copyright = g_strdup_printf (_("© %s Zander Brown"), "2019-2024");
+  copyright = g_strdup_printf (_("© %s Zander Brown"), "2019-2025");
 
   adw_show_about_dialog (widget,
                          "application-name", KGX_DISPLAY_NAME,
@@ -614,6 +641,9 @@ kgx_window_class_init (KgxWindowClass *klass)
                                             "win.find",
                                             "search-mode-enabled");
 
+  g_type_ensure (KGX_TYPE_PAGES);
+  g_type_ensure (KGX_TYPE_THEME_SWITCHER);
+
   gtk_widget_class_set_template_from_resource (widget_class,
                                                KGX_APPLICATION_PATH "kgx-window.ui");
 
@@ -637,6 +667,8 @@ kgx_window_class_init (KgxWindowClass *klass)
   gtk_widget_class_bind_template_callback (widget_class, title_or_fallback);
   gtk_widget_class_bind_template_callback (widget_class, path_as_subtitle);
   gtk_widget_class_bind_template_callback (widget_class, scale_as_label);
+  gtk_widget_class_bind_template_callback (widget_class, decoration_is_inverted);
+  gtk_widget_class_bind_template_callback (widget_class, kgx_gtk_settings_for_display);
 
   gtk_widget_class_install_action (widget_class, "tab.close", NULL, close_tab_activated);
   gtk_widget_class_install_action (widget_class, "tab.detach", NULL, detach_tab_activated);
@@ -699,18 +731,9 @@ kgx_window_init (KgxWindow *self)
   KgxWindowPrivate *priv = kgx_window_get_instance_private (self);
   GType drop_types[] = { GDK_TYPE_FILE_LIST, G_TYPE_STRING };
   g_autoptr (GtkWindowGroup) group = NULL;
-  AdwStyleManager *style_manager;
-
-  g_type_ensure (KGX_TYPE_THEME_SWITCHER);
 
   gtk_widget_init_template (GTK_WIDGET (self));
 
-  style_manager = adw_style_manager_get_default ();
-
-  g_object_bind_property (style_manager, "system-supports-color-schemes",
-                          priv->theme_switcher, "show-system",
-                          G_BINDING_SYNC_CREATE);
-
   g_binding_group_bind (priv->settings_binds, "theme",
                         priv->theme_switcher, "theme",
                         G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
